/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                TERCER GRADO DE PRIMARIA (Excale 03)
/*
/*                   **** CIENCIAS NATURALES ****
/*
/*                 Ciclo escolar evaluado: 2005 - 2006
/*_____________________________________________________________________________
/*
/*
/*    PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE LA ASIGNATURA DE
/*                    CIENCIAS NATURALES  EN FORMATO SAS
/*
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale03_2006_Alum_CN.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. La sintxis realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas varibles
/*   - Lectura de variables del archivo en formato ASCII
/*   - Declara los valores perdidos por el usuario (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale03_2006_Alum_CN.txt
/*         as como el archivo Excale03_2006_Alum_CN.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE.
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la libreria y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se crear la base de datos (tabla de datos) Excale03_2006_Alum_CN.sas7bdat.
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale03_2006_Alum_CN.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS carge los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE ELABORACIN: 9 DE OCTUBRE DE 2007
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum "C:\***\Excale03_2006_Alum_CN.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbanas Pblicas"
                       2         ="Rurales Pblicas"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privadas"
                       6         ="Generales"
                       7         ="Tcnicas"
                       8         ="Telesecundarias"
                       9         ="Privadas";
     VALUE  $modF      "UP"      ="Urbanas Pblicas"
                       "RP"      ="Rurales Pblicas"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privadas"
                       "GRAL"    ="Generales"
                       "TEC"     ="Tcnicas"
                       "TV"      ="Telesecundarias"
                       "PRIV"    ="Privadas";
     VALUE $entestdomF "999999"  ="Respuesta omitida";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadcF      1         ="Ocho aos o menos"
                       2         ="Nueve aos"
                       3         ="Diez aos"
                       4         ="Once aos o ms"
                       9         ="Respuesta omitida";
     VALUE edad1sF     1         ="Menos de Ocho aos"
                       2         ="Ocho aos"
                       3         ="Nueve aos"
                       4         ="Diez aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE RespF       0         ="Fallo"
                       1         ="Acierto"
                       5         ="Reactivo no alcanzado (se considera como no administrado)"
                       7         ="Reactivo no administrado";
RUN;



DATA INEE.Excale03_2006_Alum_CN;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $20
       id_mod             3
       mod                $4
       entest             $6
       entestdom          $6
       alumno             6
       id_instr           $16
       sexo               3
       edad               8
       edadc              3
       edad1sep           8
       edad1sepc          3
       edadn              3
       edad_ac            3
       mes_nac            3
       w_alu              8
       docente            5
       pna_01             3
       pna_02             3
       pna_03             3
       pna_04             3
       pna_05             3
       pna_06             3
       pna_07             3
       pna_08             3
       pnb_01             3
       pnb_02             3
       pnb_03             3
       pnb_05             3
       pnb_06             3
       pnb_07             3
       pnc_01             3
       pnc_02             3
       pnc_03             3
       pnc_04             3
       pnc_05             3
       pnc_06             3
       pnc_07             3
       pnd_01             3
       pnd_02             3
       pnd_03             3
       pnd_04             3
       pnd_05             3
       pnd_06             3
       pnd_07             3
       pne_01             3
       pne_02             3
       pne_03             3
       pne_04             3
       pne_05             3
       pne_06             3
       pne_07             3
       pnf_01             3
       pnf_02             3
       pnf_03             3
       pnf_04             3
       pnf_05             3
       pnf_06             3
       pnf_07             3
       pnf_08             3
       png_01             3
       png_02             3
       png_03             3
       png_04             3
       png_05             3
       png_06             3
       png_07             3
       pv1cna             8
       pv2cna             8
       pv3cna             8
       pv4cna             8
       pv5cna             8
       cnanvl1            3
       cnanvl2            3
       cnanvl3            3
       cnanvl4            3
       cnanvl5            3
       cnanvlb1           3
       cnanvlb2           3
       cnanvlb3           3
       cnanvlb4           3
       cnanvlb5           3
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
   ;

INFILE alum MISSOVER LINESIZE = 1380;
   INPUT
       nacional            1 - 1
       escuela             2 - 5
       id_ent              6 - 7
       nom_ent             8 - 27
       id_mod             28 - 28
       mod                29 - 32
       entest             33 - 38
       entestdom          39 - 44
       alumno             45 - 50
       id_instr           51 - 66
       sexo               67 - 67
       edad               68 - 72
       edadc              73 - 73
       edad1sep           74 - 89
       edad1sepc          90 - 92
       edadn              93 - 93
       edad_ac            94 - 95
       mes_nac            96 - 97
       w_alu              98 - 113
       docente           114 - 118
       pna_01            119 - 119
       pna_02            120 - 120
       pna_03            121 - 121
       pna_04            122 - 122
       pna_05            123 - 123
       pna_06            124 - 124
       pna_07            125 - 125
       pna_08            126 - 126
       pnb_01            127 - 127
       pnb_02            128 - 128
       pnb_03            129 - 129
       pnb_05            130 - 130
       pnb_06            131 - 131
       pnb_07            132 - 132
       pnc_01            133 - 133
       pnc_02            134 - 134
       pnc_03            135 - 135
       pnc_04            136 - 136
       pnc_05            137 - 137
       pnc_06            138 - 138
       pnc_07            139 - 139
       pnd_01            140 - 140
       pnd_02            141 - 141
       pnd_03            142 - 142
       pnd_04            143 - 143
       pnd_05            144 - 144
       pnd_06            145 - 145
       pnd_07            146 - 146
       pne_01            147 - 147
       pne_02            148 - 148
       pne_03            149 - 149
       pne_04            150 - 150
       pne_05            151 - 151
       pne_06            152 - 152
       pne_07            153 - 153
       pnf_01            154 - 154
       pnf_02            155 - 155
       pnf_03            156 - 156
       pnf_04            157 - 157
       pnf_05            158 - 158
       pnf_06            159 - 159
       pnf_07            160 - 160
       pnf_08            161 - 161
       png_01            162 - 162
       png_02            163 - 163
       png_03            164 - 164
       png_04            165 - 165
       png_05            166 - 166
       png_06            167 - 167
       png_07            168 - 168
       pv1cna            169 - 184
       pv2cna            185 - 200
       pv3cna            201 - 216
       pv4cna            217 - 232
       pv5cna            233 - 248
       cnanvl1           249 - 249
       cnanvl2           250 - 250
       cnanvl3           251 - 251
       cnanvl4           252 - 252
       cnanvl5           253 - 253
       cnanvlb1          254 - 254
       cnanvlb2          255 - 255
       cnanvlb3          256 - 256
       cnanvlb4          257 - 257
       cnanvlb5          258 - 258
       wvarstrr          259 - 260
       w_fstr1           261 - 274
       w_fstr2           275 - 288
       w_fstr3           289 - 302
       w_fstr4           303 - 316
       w_fstr5           317 - 330
       w_fstr6           331 - 344
       w_fstr7           345 - 358
       w_fstr8           359 - 372
       w_fstr9           373 - 386
       w_fstr10          387 - 400
       w_fstr11          401 - 414
       w_fstr12          415 - 428
       w_fstr13          429 - 442
       w_fstr14          443 - 456
       w_fstr15          457 - 470
       w_fstr16          471 - 484
       w_fstr17          485 - 498
       w_fstr18          499 - 512
       w_fstr19          513 - 526
       w_fstr20          527 - 540
       w_fstr21          541 - 554
       w_fstr22          555 - 568
       w_fstr23          569 - 582
       w_fstr24          583 - 596
       w_fstr25          597 - 610
       w_fstr26          611 - 624
       w_fstr27          625 - 638
       w_fstr28          639 - 652
       w_fstr29          653 - 666
       w_fstr30          667 - 680
       w_fstr31          681 - 694
       w_fstr32          695 - 708
       w_fstr33          709 - 722
       w_fstr34          723 - 736
       w_fstr35          737 - 750
       w_fstr36          751 - 764
       w_fstr37          765 - 778
       w_fstr38          779 - 792
       w_fstr39          793 - 806
       w_fstr40          807 - 820
       w_fstr41          821 - 834
       w_fstr42          835 - 848
       w_fstr43          849 - 862
       w_fstr44          863 - 876
       w_fstr45          877 - 890
       w_fstr46          891 - 904
       w_fstr47          905 - 918
       w_fstr48          919 - 932
       w_fstr49          933 - 946
       w_fstr50          947 - 960
       w_fstr51          961 - 974
       w_fstr52          975 - 988
       w_fstr53          989 - 1002
       w_fstr54         1003 - 1016
       w_fstr55         1017 - 1030
       w_fstr56         1031 - 1044
       w_fstr57         1045 - 1058
       w_fstr58         1059 - 1072
       w_fstr59         1073 - 1086
       w_fstr60         1087 - 1100
       w_fstr61         1101 - 1114
       w_fstr62         1115 - 1128
       w_fstr63         1129 - 1142
       w_fstr64         1143 - 1156
       w_fstr65         1157 - 1170
       w_fstr66         1171 - 1184
       w_fstr67         1185 - 1198
       w_fstr68         1199 - 1212
       w_fstr69         1213 - 1226
       w_fstr70         1227 - 1240
       w_fstr71         1241 - 1254
       w_fstr72         1255 - 1268
       w_fstr73         1269 - 1282
       w_fstr74         1283 - 1296
       w_fstr75         1297 - 1310
       w_fstr76         1311 - 1324
       w_fstr77         1325 - 1338
       w_fstr78         1339 - 1352
       w_fstr79         1353 - 1366
       w_fstr80         1367 - 1380
   ;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       entestdom   = "Variable auxiliar para identificar los dominios de estudio (subpoblaciones donde se reportan resultados) a nivel de modalidad al interior de las entidades"
       alumno      = "Identifcador del alumno"
       id_instr    = "Identificador del cuadernillo de examen"
       sexo        = "Sexo del alumno"
       edad        = "Edad del alumno al mes de mayo de 2006, en aos (al momento de la aplicacin)"
       edadc       = "Edad del alumno al mes de mayo de 2006, codificada (al momento de la aplicacin)"
       edad1sep    = "Edad del alumno al mes de septiembre de 2005, en aos (al inicio del ciclo escolar)"
       edad1sepc   = "Edad del alumno al mes de septiembre de 2005, codificada (al inicio del ciclo escolar)"
       edadn       = "Edad normativa"
       edad_ac     = "Edad en aos cumplidos (al momento de la aplicacin)"
       mes_nac     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       w_alu       = "Peso muestral o ponderador del alumno"
       docente     = "Identificador del docente que imparte clases al alumno"
       pna_01      = "Reactivo PNA_01. Identificar la trayectoria que describe un objeto en movimiento."
       pna_02      = "Reactivo PNA_02. Identificar la funcin que realiza uno de los rganos del aparato digestivo, sealado en un esquema."
       pna_03      = "Reactivo PNA_03. Comprender que en una herida leve la sangre deja de salir debido a que se coagula."
       pna_04      = "Reactivo PNA_04. Relacionar la funcin del aparato respiratorio con un modelo que represente su funcionamiento."
       pna_05      = "Reactivo PNA_05. Reconocer los cuidados  que requieren los rboles."
       pna_06      = "Reactivo PNA_06. Reflexionar acerca de lo que ocurrira si alguno de los eslabones de una cadena alimentaria se eliminara."
       pna_07      = "Reactivo PNA_07. Relacionar un recurso natural con el producto que se obtiene de l."
       pna_08      = "Reactivo PNA_08. Comprender por qu es importante cuidar el agua de una laguna."
       pnb_01      = "Reactivo PNB_01. Identificar el dibujo que represente el lugar con ms posibilidades de tener aire limpio."
       pnb_02      = "Reactivo PNB_02. Distinguir ,entre varios alimentos, el que tenga el ms alto valor nutritivo."
       pnb_03      = "Reactivo PNB_03. Distinguir el tipo de respiracin que tienen algunos animales domsticos."
       pnb_05      = "Reactivo PNB_05. Identificar los riesgos de consumir alimentos preparados sin las correctas medidas de higiene."
       pnb_06      = "Reactivo PNB_06. Identificar lo primero que se debe hacer cuando se tiene una herida leve."
       pnb_07      = "Reactivo PNB_07. Reconocer una recomendacin para mantener sano el sistema circulatorio."
       pnc_01      = "Reactivo PNC_01. Identificar una situacin donde hubo movimiento."
       pnc_02      = "Reactivo PNC_02. Identificar el alimento que falta para integrar un desayuno completo, a partir de la clasificacin de los alimentos basada en los nutrimentos que contienen."
       pnc_03      = "Reactivo PNC_03. Identificar lugares que ofrecen riesgo de sufrir accidentes."
       pnc_04      = "Reactivo PNC_04. Identificar uno de los sntomas que ocasiona comer en exceso."
       pnc_05      = "Reactivo PNC_05. Identificar las principales partes de las plantas y sus funciones."
       pnc_06      = "Reactivo PNC_06. Comprender que los seres vivos no pueden vivir sin respirar."
       pnc_07      = "Reactivo PNC_07. Identificar una forma de ahorrar agua."
       pnd_01      = "Reactivo PND_01. Identificar la forma correcta de cruzar una calle llena de vehculos."
       pnd_02      = "Reactivo PND_02. Distinguir, entre varias actividades, aqulla en la que el movimiento del corazn sea ms acelerado."
       pnd_03      = "Reactivo PND_03. Identificar la funcin de uno de principales rganos del aparato respiratorio."
       pnd_04      = "Reactivo PND_04. Identificar grupos de alimentos ricos en vitaminas y minerales."
       pnd_05      = "Reactivo PND_05. Reconocer que el agua es indispensable para los seres vivos."
       pnd_06      = "Reactivo PND_06. Reconocer que el agua que sale por la orina ayuda a eliminar desechos."
       pnd_07      = "Reactivo PND_07. Identificar un producto, a partir de algunos elementos de su proceso de elaboracin."
       pne_01      = "Reactivo PNE_01. Identificar los daos que los alimentos de escaso valor nutritivo pueden ocasionar a la salud."
       pne_02      = "Reactivo PNE_02. Reconocer algunas caractersticas del proceso de la digestin."
       pne_03      = "Reactivo PNE_03. Reconocer los riesgos que se tienen al beber agua que no es potable."
       pne_04      = "Reactivo PNE_04. Identificar una de las acciones humanas que contaminan el aire."
       pne_05      = "Reactivo PNE_05. Identificar un organismo carnvoro."
       pne_06      = "Reactivo PNE_06. Identificar una accin en la que se reutilicen desechos."
       pne_07      = "Reactivo PNE_07. Reconocer una de las formas en que se usa el agua para el aseo."
       pnf_01      = "Reactivo PNF_01. Identificar cundo se forma el vapor, en un esquema del ciclo del agua."
       pnf_02      = "Reactivo PNF_02. Reconocer una accin mediante la cual se previene una enfermedad del aparato respiratorio."
       pnf_03      = "Reactivo PNF_03. Identiicar los cuidados principales para conservar los dientes sanos y en buen estado."
       pnf_04      = "Reactivo PNF_04. Identificar cmo se puede purificar el agua de pozo."
       pnf_05      = "Reactivo PNF_05. Identificar una planta que sirve de alimento a los seres humanos."
       pnf_06      = "Reactivo PNF_06. Clasificar los desechos en orgnicos e inorgnicos."
       pnf_07      = "Reactivo PNF_07. Reconocer que el aire es indispensable para la vida."
       pnf_08      = "Reactivo PNF_08. Identificar una accin til para cuidar los bosques."
       png_01      = "Reactivo PNG_01. Identificar los cambios de estado del agua."
       png_02      = "Reactivo PNG_02. Identificar algunas consecuencias de eliminar las frutas de la dieta diaria."
       png_03      = "Reactivo PNG_03. Identificar uno de los mtodos para purificar el agua."
       png_04      = "Reactivo PNG_04. Identificar un alimento cuya preparacin requiere de calor."
       png_05      = "Reactivo PNG_05. Identificar a los organismos descomponedores en una cadena alimentaria."
       png_06      = "Reactivo PNG_06. Reflexionar acerca de la presencia del aire por medio de un experimento."
       png_07      = "Reactivo PNG_07. Reconocer que tirar basura en los ros y lagos puede ocasionar enfermedades a las personas."
       pv1cna      = "Primer valor plausible de Ciencias Naturales"
       pv2cna      = "Segundo valor plausible de Ciencias Naturales"
       pv3cna      = "Tercer valor plausible de Ciencias Naturales"
       pv4cna      = "Cuarto valor plausible de Ciencias Naturales"
       pv5cna      = "Quinto valor plausible de Ciencias Naturales"
       cnanvl1     = "Nivel de logro en Ciencias Naturales. Asociado a pv1CNa. (Cuatro niveles)"
       cnanvl2     = "Nivel de logro en Ciencias Naturales. Asociado a pv2CNa. (Cuatro niveles)"
       cnanvl3     = "Nivel de logro en Ciencias Naturales. Asociado a pv3CNa. (Cuatro niveles)"
       cnanvl4     = "Nivel de logro en Ciencias Naturales. Asociado a pv4CNa. (Cuatro niveles)"
       cnanvl5     = "Nivel de logro en Ciencias Naturales. Asociado a pv5CNa. (Cuatro niveles)"
       cnanvlb1    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a pv1CNa."
       cnanvlb2    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a pv2CNa."
       cnanvlb3    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a pv3CNa."
       cnanvlb4    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a pv4CNa."
       cnanvlb5    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a pv5CNa."
       wvarstrr    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
   ;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char20.
       id_mod             id_modF.
       mod                $modF.
       entest             $char6.
       entestdom          $entestdomF.
       alumno             6.
       id_instr           $char16.
       sexo               sexoF.
       edadc              edadcF.
       edad1sepc          edad1sF.
       edadn              edadnF.
       edad_ac            edad_acF.
       mes_nac            mes_nacF.
       docente            docenteF.
       pna_01             RespF.
       pna_02             RespF.
       pna_03             RespF.
       pna_04             RespF.
       pna_05             RespF.
       pna_06             RespF.
       pna_07             RespF.
       pna_08             RespF.
       pnb_01             RespF.
       pnb_02             RespF.
       pnb_03             RespF.
       pnb_05             RespF.
       pnb_06             RespF.
       pnb_07             RespF.
       pnc_01             RespF.
       pnc_02             RespF.
       pnc_03             RespF.
       pnc_04             RespF.
       pnc_05             RespF.
       pnc_06             RespF.
       pnc_07             RespF.
       pnd_01             RespF.
       pnd_02             RespF.
       pnd_03             RespF.
       pnd_04             RespF.
       pnd_05             RespF.
       pnd_06             RespF.
       pnd_07             RespF.
       pne_01             RespF.
       pne_02             RespF.
       pne_03             RespF.
       pne_04             RespF.
       pne_05             RespF.
       pne_06             RespF.
       pne_07             RespF.
       pnf_01             RespF.
       pnf_02             RespF.
       pnf_03             RespF.
       pnf_04             RespF.
       pnf_05             RespF.
       pnf_06             RespF.
       pnf_07             RespF.
       pnf_08             RespF.
       png_01             RespF.
       png_02             RespF.
       png_03             RespF.
       png_04             RespF.
       png_05             RespF.
       png_06             RespF.
       png_07             RespF.
       cnanvl1            1.
       cnanvl2            1.
       cnanvl3            1.
       cnanvl4            1.
       cnanvl5            1.
       cnanvlb1           1.
       cnanvlb2           1.
       cnanvlb3           1.
       cnanvlb4           1.
       cnanvlb5           1.
       wvarstrr           2.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Multiple.
/*   .S o S = No contestado.
/*************************************************************************/
   IF entestdom = "999999"  THEN entestdom = "S";
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;

   ARRAY perdidos1(4)  sexo edadc edad1sepc edadn;
   DO  i=1 TO 4;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(4)  edad edad1sep edad_ac mes_nac;
   DO  i=1 TO 4;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(50)
                   pna_01 pna_02 pna_03 pna_04 pna_05 pna_06 pna_07 pna_08 pnb_01 pnb_02
                   pnb_03 pnb_05 pnb_06 pnb_07 pnc_01 pnc_02 pnc_03 pnc_04 pnc_05 pnc_06
                   pnc_07 pnd_01 pnd_02 pnd_03 pnd_04 pnd_05 pnd_06 pnd_07 pne_01 pne_02
                   pne_03 pne_04 pne_05 pne_06 pne_07 pnf_01 pnf_02 pnf_03 pnf_04 pnf_05
                   pnf_06 pnf_07 pnf_08 png_01 png_02 png_03 png_04 png_05 png_06 png_07;
   DO  i=1 TO 50;
          IF (perdidos3{i} = 5 OR  perdidos3{i} = 7)  THEN  perdidos3{i} = .N;
   END;

   drop i;
RUN;
